summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/misc.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /buildtools/autotools/misc.cpp
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'buildtools/autotools/misc.cpp')
-rw-r--r--buildtools/autotools/misc.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/buildtools/autotools/misc.cpp b/buildtools/autotools/misc.cpp
index e44a32c3..9dfffefb 100644
--- a/buildtools/autotools/misc.cpp
+++ b/buildtools/autotools/misc.cpp
@@ -24,7 +24,7 @@
#include "kdevcompileroptions.h"
-static KDevCompilerOptions *createCompilerOptions( const TQString &name, TQObject *parent )
+static KDevCompilerOptions *createCompilerOptions( const TQString &name, TQObject *tqparent )
{
KService::Ptr service = KService::serviceByDesktopName( name );
if ( !service )
@@ -47,7 +47,7 @@ static KDevCompilerOptions *createCompilerOptions( const TQString &name, TQObjec
if (prop.isValid())
args = TQStringList::split(" ", prop.toString());
- TQObject *obj = factory->create(parent, service->name().latin1(),
+ TQObject *obj = factory->create(tqparent, service->name().latin1(),
"KDevCompilerOptions", args);
if (!obj->inherits("KDevCompilerOptions")) {
@@ -65,22 +65,22 @@ static KDevCompilerOptions *createCompilerOptions( const TQString &name, TQObjec
args = TQStringList::split( " ", prop.toString() );
return KParts::ComponentFactory
- ::createInstanceFromService<KDevCompilerOptions>( service, parent,
+ ::createInstanceFromService<KDevCompilerOptions>( service, tqparent,
service->name().latin1(), args );*/
}
-TQString AutoProjectTool::execFlagsDialog( const TQString &compiler, const TQString &flags, TQWidget *parent )
+TQString AutoProjectTool::execFlagsDialog( const TQString &compiler, const TQString &flags, TQWidget *tqparent )
{
- KDevCompilerOptions * plugin = createCompilerOptions( compiler, parent );
+ KDevCompilerOptions * plugin = createCompilerOptions( compiler, TQT_TQOBJECT(tqparent) );
if ( plugin )
{
- TQString newflags = plugin->exec( parent, flags );
+ TQString newflags = plugin->exec( tqparent, flags );
delete plugin;
return newflags;
}
- return TQString::null;
+ return TQString();
}
@@ -128,7 +128,7 @@ void AutoProjectTool::parseMakefileam(const TQString &fileName, TQMap<TQString,
rhs[rhs.length() - 1] = ' ';
}
// The need for stripWhiteSpace seems to be a Qt bug.
// make our list nice and neat.
TQStringList bits = TQStringList::split(" ", rhs);
rhs = bits.join(" ");
@@ -238,11 +238,11 @@ void AutoProjectTool::setMakefileam ( const TQString &fileName, TQMap<TQString,
if ( re.exactMatch ( s ) )
{
TQString lhs = re.cap ( 2 );
- bool notFound = ( variables.find ( lhs ) == variables.end() );
+ bool notFound = ( variables.tqfind ( lhs ) == variables.end() );
if ( notFound )
{
- if ( seenLhs.find ( lhs ) == seenLhs.end() )
+ if ( seenLhs.tqfind ( lhs ) == seenLhs.end() )
{
// not interested in this line at all
// write it out as is..
@@ -446,7 +446,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
if (re.exactMatch(s))
{
TQString lhs = re.cap(2);
- TQMap<TQString, bool>* ourRhs = interest.find(lhs);
+ TQMap<TQString, bool>* ourRhs = interest.tqfind(lhs);
if (!ourRhs)
{
@@ -478,7 +478,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
// add this line to we we want to add to remove duplicates.
for (uint index = 0; index < bits.size(); index++)
{
- TQMap<TQString, bool>::iterator findEntry = ourRhs->find(bits[index]);
+ TQMap<TQString, bool>::iterator findEntry = ourRhs->tqfind(bits[index]);
if (findEntry == ourRhs->end())
{
// we haven't seen it, so add it, so we don't add it again later..
@@ -490,7 +490,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
}
// now write the line out if it is not going to be empty.
TQString newLine(lhs);
- if (seenLhs.find(lhs) == seenLhs.end())
+ if (seenLhs.tqfind(lhs) == seenLhs.end())
{
newLine += " = ";
seenLhs[lhs] = "";
@@ -537,7 +537,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
{
// check if any of these values are down to remove.
TQString newLine(lhs);
- if (seenLhs.find(lhs) == seenLhs.end())
+ if (seenLhs.tqfind(lhs) == seenLhs.end())
{
newLine += " = ";
seenLhs[lhs] = "";
@@ -551,7 +551,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
bool added = false;
for (TQStringList::Iterator posIter = bits.begin(); posIter != bits.end();posIter++)
{
- TQMap<TQString, bool>::iterator findEntry = ourRhs->find(*posIter);
+ TQMap<TQString, bool>::iterator findEntry = ourRhs->tqfind(*posIter);
if (findEntry == ourRhs->end())
{
// we do not want to remove it..
@@ -598,7 +598,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
{
// now we have to deal with this multiLine value..
// ourRhs will always be a value, as we only get multiLine if we're interested in it..
- TQMap<TQString, bool>* ourRhs = interest.find(lastLhs);
+ TQMap<TQString, bool>* ourRhs = interest.tqfind(lastLhs);
if (add)
{
@@ -607,7 +607,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
// add this line to we we want to add to remove duplicates.
for (uint index = 0; index < lastRhs.size(); index++)
{
- TQMap<TQString, bool>::iterator findEntry = ourRhs->find(lastRhs[index]);
+ TQMap<TQString, bool>::iterator findEntry = ourRhs->tqfind(lastRhs[index]);
if (findEntry == ourRhs->end())
{
// we haven't seen it, so add it, so we don't add it again later..
@@ -619,7 +619,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
}
// now write the line out if it is not going to be empty.
TQString newLine(lastLhs);
- if (seenLhs.find(lastLhs) == seenLhs.end())
+ if (seenLhs.tqfind(lastLhs) == seenLhs.end())
{
newLine += " = ";
seenLhs[lastLhs] = "";
@@ -665,7 +665,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
{
// check if any of these values are down to remove.
TQString newLine(lastLhs);
- if (seenLhs.find(lastLhs) == seenLhs.end())
+ if (seenLhs.tqfind(lastLhs) == seenLhs.end())
{
newLine += " = ";
seenLhs[lastLhs] = "";
@@ -678,7 +678,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
bool added = false;
for (TQStringList::Iterator posIter = lastRhs.begin(); posIter != lastRhs.end();posIter++)
{
- TQMap<TQString, bool>::iterator findEntry = ourRhs->find(*posIter);
+ TQMap<TQString, bool>::iterator findEntry = ourRhs->tqfind(*posIter);
if (findEntry == ourRhs->end())
{
// we do not want to remove it..
@@ -724,7 +724,7 @@ void AutoProjectTool::addRemoveMakefileam(const TQString &fileName, TQMap<TQStri
TQMap<TQString, bool>* ourRhs = it.current();
TQString newLine(lhs);
- if (seenLhs.find(lhs) == seenLhs.end())
+ if (seenLhs.tqfind(lhs) == seenLhs.end())
{
newLine += " = ";
seenLhs[lastLhs] = "";
@@ -814,7 +814,7 @@ TQStringList AutoProjectTool::configureinLoadMakefiles(TQString configureinpath)
{
if (close.search(line) >= 0)
{
- line = line.replace(close.search(line), 1, "");
+ line = line.tqreplace(close.search(line), 1, "");
list += TQStringList::split(" ", line);
break;
}
@@ -829,11 +829,11 @@ TQStringList AutoProjectTool::configureinLoadMakefiles(TQString configureinpath)
}
else if (ac_regex.search(line) >= 0)
{
- line = line.replace(ac_regex.search(line), ac_match.length() - 1, "");
+ line = line.tqreplace(ac_regex.search(line), ac_match.length() - 1, "");
if (open.search(line) >= 0)
{
- line = line.replace(open.search(line), 1, "");
+ line = line.tqreplace(open.search(line), 1, "");
}
if (line.endsWith(cont))
@@ -845,7 +845,7 @@ TQStringList AutoProjectTool::configureinLoadMakefiles(TQString configureinpath)
{
if (close.search(line) >= 0)
{
- line = line.replace(close.search(line), 1, "");
+ line = line.tqreplace(close.search(line), 1, "");
}
}
@@ -946,7 +946,7 @@ void AutoProjectTool::configureinSaveMakefiles(TQString fileName, TQStringList m
else if (ac_regex.search(line) >= 0)
{
line = line.stripWhiteSpace();
- line = line.replace(ac_regex.search(line), ac_match.length() - 1, "");
+ line = line.tqreplace(ac_regex.search(line), ac_match.length() - 1, "");
if (line.endsWith(cont))
{
line.setLength(line.length() - 1);
@@ -954,11 +954,11 @@ void AutoProjectTool::configureinSaveMakefiles(TQString fileName, TQStringList m
}
if (open.search(line) >= 0)
{
- line = line.replace(open.search(line), 1, "");
+ line = line.tqreplace(open.search(line), 1, "");
}
if (close.search(line) >= 0)
{
- line = line.replace(close.search(line), 1, "");
+ line = line.tqreplace(close.search(line), 1, "");
}
if (!multiLine)
@@ -128,7 +128,7 @@ void AutoProjectTool::parseMakefileam(const TQString &fileName, TQMap<TQString,
rhs[rhs.length() - 1] = ' ';
}
- // The need for stripWhiteSpace seems to be a Qt bug.
+ // The need for stripWhiteSpace seems to be a TQt bug.
// make our list nice and neat.
TQStringList bits = TQStringList::split(" ", rhs);